
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....tensorflow.core.profiler.protobuf import diagnostics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2
from .....tensorflow.core.profiler.protobuf import input_pipeline_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_input__pipeline__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/overview_page.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n5tensorflow/core/profiler/protobuf/overview_page.proto\x12\x13tensorflow.profiler\x1a\x19google/protobuf/any.proto\x1a3tensorflow/core/profiler/protobuf/diagnostics.proto\x1a6tensorflow/core/profiler/protobuf/input_pipeline.proto"\xc2\x01\n\x0cOverviewTfOp\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08category\x18\x02 \x01(\t\x12\x1a\n\x12self_time_fraction\x18\x03 \x01(\x01\x12 \n\x18cumulative_time_fraction\x18\x04 \x01(\x01\x12\x11\n\tflop_rate\x18\x05 \x01(\x01\x12!\n\x19is_op_tensorcore_eligible\x18\x06 \x01(\x08\x12\x1e\n\x16is_op_using_tensorcore\x18\x07 \x01(\x08"\xf5\x04\n\x14OverviewPageAnalysis\x12\x1f\n\x17mxu_utilization_percent\x18\x01 \x01(\x01\x12 \n\x18device_idle_time_percent\x18\x02 \x01(\x01\x12\x1e\n\x16host_idle_time_percent\x18\x03 \x01(\x01\x129\n\x0etop_device_ops\x18\x04 \x03(\x0b2!.tensorflow.profiler.OverviewTfOp\x12\x13\n\x0bremark_text\x18\x05 \x01(\t\x12\x14\n\x0cremark_color\x18\x06 \x01(\t\x12:\n2flop_rate_utilization_relative_to_roofline_percent\x18\x07 \x01(\x01\x12:\n2memory_bw_utilization_relative_to_hw_limit_percent\x18\x08 \x01(\x01\x12$\n\x1cdevice_compute_16bit_percent\x18\t \x01(\x01\x12$\n\x1cdevice_compute_32bit_percent\x18\n \x01(\x01\x12\x1a\n\x12host_tf_op_percent\x18\x0b \x01(\x01\x12\x1c\n\x14device_tf_op_percent\x18\x0c \x01(\x01\x12\x18\n\x10host_trace_level\x18\r \x01(\r\x12"\n\x1ahost_op_time_eager_percent\x18\x0e \x01(\x01\x12$\n\x1cdevice_op_time_eager_percent\x18\x0f \x01(\x01\x122\n*device_op_time_outside_compilation_percent\x18\x10 \x01(\x01"\x1f\n\x0fOverviewPageTip\x12\x0c\n\x04link\x18\x01 \x01(\t"\xff\x01\n\x15GenericRecommendation\x12 \n\x18kernel_launch_bottleneck\x18\x01 \x01(\t\x12\x1f\n\x17kernel_launch_statement\x18\x02 \x01(\t\x12\x1c\n\x14all_other_bottleneck\x18\x03 \x01(\t\x12\x1b\n\x13all_other_statement\x18\x04 \x01(\t\x12\x1b\n\x13precision_statement\x18\x05 \x01(\t\x12%\n\x1ddevice_collectives_bottleneck\x18\x06 \x01(\t\x12$\n\x1cdevice_collectives_statement\x18\x07 \x01(\t"\xdf\x04\n\x1aOverviewPageRecommendation\x12\x12\n\nbottleneck\x18\x01 \x01(\t\x12\x11\n\tstatement\x18\x02 \x01(\t\x128\n\ninput_tips\x18\x0b \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x12\x18\n\x10output_statement\x18\t \x01(\t\x12\x1c\n\x14eager_statement_html\x18\x0c \x01(\t\x12*\n"outside_compilation_statement_html\x18\r \x01(\t\x12"\n\x1atf_function_statement_html\x18\n \x01(\t\x127\n\thost_tips\x18\x03 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x129\n\x0bdevice_tips\x18\x04 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x12@\n\x12documentation_tips\x18\x05 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x12,\n\x0erecommendation\x18\x06 \x01(\x0b2\x14.google.protobuf.Any\x126\n\x08faq_tips\x18\x07 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip\x12<\n\x0einference_tips\x18\x08 \x03(\x0b2$.tensorflow.profiler.OverviewPageTip"\x80\x01\n"OverviewPageHostIndependentJobInfo\x12\x13\n\x0bchange_list\x18\x01 \x01(\x03\x12\x12\n\nbuild_time\x18\x02 \x01(\x03\x12\x14\n\x0cbuild_target\x18\x03 \x01(\t\x12\x1b\n\x13profile_duration_ms\x18\x04 \x01(\r"\x8b\x01\n OverviewPageHostDependentJobInfo\x12\x0f\n\x07host_id\x18\x01 \x01(\t\x12\x14\n\x0ccommand_line\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\x03\x12\x13\n\x0bbns_address\x18\x04 \x01(\t\x12\x17\n\x0fprofile_time_ns\x18\x05 \x01(\x04"\x80\x04\n\x1aOverviewPageRunEnvironment\x12\x12\n\nhost_count\x18\x01 \x01(\x05\x12\x12\n\ntask_count\x18\x02 \x01(\x05\x12Q\n\thostnames\x18\x03 \x03(\x0b2>.tensorflow.profiler.OverviewPageRunEnvironment.HostnamesEntry\x12\x13\n\x0bdevice_type\x18\x04 \x01(\t\x12\x19\n\x11device_core_count\x18\x05 \x01(\x05\x12\x1b\n\x13per_core_batch_size\x18\x06 \x01(\x05\x12Z\n\x19host_independent_job_info\x18\x07 \x01(\x0b27.tensorflow.profiler.OverviewPageHostIndependentJobInfo\x12V\n\x17host_dependent_job_info\x18\x08 \x03(\x0b25.tensorflow.profiler.OverviewPageHostDependentJobInfo\x12\x15\n\rreplica_count\x18\t \x01(\x05\x12\x1d\n\x15num_cores_per_replica\x18\n \x01(\x05\x1a0\n\x0eHostnamesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x028\x01"\xf1\x02\n\x0cOverviewPage\x12H\n\x0frun_environment\x18\x06 \x01(\x0b2/.tensorflow.profiler.OverviewPageRunEnvironment\x12H\n\x0einput_analysis\x18\x02 \x01(\x0b20.tensorflow.profiler.InputPipelineAnalysisResult\x12;\n\x08analysis\x18\x03 \x01(\x0b2).tensorflow.profiler.OverviewPageAnalysis\x12G\n\x0erecommendation\x18\x04 \x01(\x0b2/.tensorflow.profiler.OverviewPageRecommendation\x125\n\x0bdiagnostics\x18\x08 \x01(\x0b2 .tensorflow.profiler.DiagnosticsJ\x04\x08\x01\x10\x02J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08b\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_input__pipeline__pb2.DESCRIPTOR])
_OVERVIEWTFOP = _descriptor.Descriptor(name='OverviewTfOp', full_name='tensorflow.profiler.OverviewTfOp', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.OverviewTfOp.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='category', full_name='tensorflow.profiler.OverviewTfOp.category', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='self_time_fraction', full_name='tensorflow.profiler.OverviewTfOp.self_time_fraction', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cumulative_time_fraction', full_name='tensorflow.profiler.OverviewTfOp.cumulative_time_fraction', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='flop_rate', full_name='tensorflow.profiler.OverviewTfOp.flop_rate', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_op_tensorcore_eligible', full_name='tensorflow.profiler.OverviewTfOp.is_op_tensorcore_eligible', index=5, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_op_using_tensorcore', full_name='tensorflow.profiler.OverviewTfOp.is_op_using_tensorcore', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=215, serialized_end=409)
_OVERVIEWPAGEANALYSIS = _descriptor.Descriptor(name='OverviewPageAnalysis', full_name='tensorflow.profiler.OverviewPageAnalysis', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='mxu_utilization_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.mxu_utilization_percent', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_idle_time_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_idle_time_percent', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_idle_time_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.host_idle_time_percent', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='top_device_ops', full_name='tensorflow.profiler.OverviewPageAnalysis.top_device_ops', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='remark_text', full_name='tensorflow.profiler.OverviewPageAnalysis.remark_text', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='remark_color', full_name='tensorflow.profiler.OverviewPageAnalysis.remark_color', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='flop_rate_utilization_relative_to_roofline_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.flop_rate_utilization_relative_to_roofline_percent', index=6, number=7, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_bw_utilization_relative_to_hw_limit_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.memory_bw_utilization_relative_to_hw_limit_percent', index=7, number=8, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_compute_16bit_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_compute_16bit_percent', index=8, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_compute_32bit_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_compute_32bit_percent', index=9, number=10, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_tf_op_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.host_tf_op_percent', index=10, number=11, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_tf_op_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_tf_op_percent', index=11, number=12, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_trace_level', full_name='tensorflow.profiler.OverviewPageAnalysis.host_trace_level', index=12, number=13, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_op_time_eager_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.host_op_time_eager_percent', index=13, number=14, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_op_time_eager_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_op_time_eager_percent', index=14, number=15, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_op_time_outside_compilation_percent', full_name='tensorflow.profiler.OverviewPageAnalysis.device_op_time_outside_compilation_percent', index=15, number=16, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=412, serialized_end=1041)
_OVERVIEWPAGETIP = _descriptor.Descriptor(name='OverviewPageTip', full_name='tensorflow.profiler.OverviewPageTip', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='link', full_name='tensorflow.profiler.OverviewPageTip.link', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1043, serialized_end=1074)
_GENERICRECOMMENDATION = _descriptor.Descriptor(name='GenericRecommendation', full_name='tensorflow.profiler.GenericRecommendation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='kernel_launch_bottleneck', full_name='tensorflow.profiler.GenericRecommendation.kernel_launch_bottleneck', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kernel_launch_statement', full_name='tensorflow.profiler.GenericRecommendation.kernel_launch_statement', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_other_bottleneck', full_name='tensorflow.profiler.GenericRecommendation.all_other_bottleneck', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_other_statement', full_name='tensorflow.profiler.GenericRecommendation.all_other_statement', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='precision_statement', full_name='tensorflow.profiler.GenericRecommendation.precision_statement', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_bottleneck', full_name='tensorflow.profiler.GenericRecommendation.device_collectives_bottleneck', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_collectives_statement', full_name='tensorflow.profiler.GenericRecommendation.device_collectives_statement', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1077, serialized_end=1332)
_OVERVIEWPAGERECOMMENDATION = _descriptor.Descriptor(name='OverviewPageRecommendation', full_name='tensorflow.profiler.OverviewPageRecommendation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='bottleneck', full_name='tensorflow.profiler.OverviewPageRecommendation.bottleneck', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='statement', full_name='tensorflow.profiler.OverviewPageRecommendation.statement', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.input_tips', index=2, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_statement', full_name='tensorflow.profiler.OverviewPageRecommendation.output_statement', index=3, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='eager_statement_html', full_name='tensorflow.profiler.OverviewPageRecommendation.eager_statement_html', index=4, number=12, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='outside_compilation_statement_html', full_name='tensorflow.profiler.OverviewPageRecommendation.outside_compilation_statement_html', index=5, number=13, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_function_statement_html', full_name='tensorflow.profiler.OverviewPageRecommendation.tf_function_statement_html', index=6, number=10, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.host_tips', index=7, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.device_tips', index=8, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='documentation_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.documentation_tips', index=9, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='recommendation', full_name='tensorflow.profiler.OverviewPageRecommendation.recommendation', index=10, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='faq_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.faq_tips', index=11, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='inference_tips', full_name='tensorflow.profiler.OverviewPageRecommendation.inference_tips', index=12, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1335, serialized_end=1942)
_OVERVIEWPAGEHOSTINDEPENDENTJOBINFO = _descriptor.Descriptor(name='OverviewPageHostIndependentJobInfo', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='change_list', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo.change_list', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='build_time', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo.build_time', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='build_target', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo.build_target', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_duration_ms', full_name='tensorflow.profiler.OverviewPageHostIndependentJobInfo.profile_duration_ms', index=3, number=4, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1945, serialized_end=2073)
_OVERVIEWPAGEHOSTDEPENDENTJOBINFO = _descriptor.Descriptor(name='OverviewPageHostDependentJobInfo', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_id', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.host_id', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='command_line', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.command_line', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_time', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.start_time', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bns_address', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.bns_address', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_time_ns', full_name='tensorflow.profiler.OverviewPageHostDependentJobInfo.profile_time_ns', index=4, number=5, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2076, serialized_end=2215)
_OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY = _descriptor.Descriptor(name='HostnamesEntry', full_name='tensorflow.profiler.OverviewPageRunEnvironment.HostnamesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.OverviewPageRunEnvironment.HostnamesEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.OverviewPageRunEnvironment.HostnamesEntry.value', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2682, serialized_end=2730)
_OVERVIEWPAGERUNENVIRONMENT = _descriptor.Descriptor(name='OverviewPageRunEnvironment', full_name='tensorflow.profiler.OverviewPageRunEnvironment', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='host_count', full_name='tensorflow.profiler.OverviewPageRunEnvironment.host_count', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='task_count', full_name='tensorflow.profiler.OverviewPageRunEnvironment.task_count', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hostnames', full_name='tensorflow.profiler.OverviewPageRunEnvironment.hostnames', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.profiler.OverviewPageRunEnvironment.device_type', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_core_count', full_name='tensorflow.profiler.OverviewPageRunEnvironment.device_core_count', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='per_core_batch_size', full_name='tensorflow.profiler.OverviewPageRunEnvironment.per_core_batch_size', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_independent_job_info', full_name='tensorflow.profiler.OverviewPageRunEnvironment.host_independent_job_info', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_dependent_job_info', full_name='tensorflow.profiler.OverviewPageRunEnvironment.host_dependent_job_info', index=7, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='replica_count', full_name='tensorflow.profiler.OverviewPageRunEnvironment.replica_count', index=8, number=9, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_replica', full_name='tensorflow.profiler.OverviewPageRunEnvironment.num_cores_per_replica', index=9, number=10, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2218, serialized_end=2730)
_OVERVIEWPAGE = _descriptor.Descriptor(name='OverviewPage', full_name='tensorflow.profiler.OverviewPage', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='run_environment', full_name='tensorflow.profiler.OverviewPage.run_environment', index=0, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_analysis', full_name='tensorflow.profiler.OverviewPage.input_analysis', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='analysis', full_name='tensorflow.profiler.OverviewPage.analysis', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='recommendation', full_name='tensorflow.profiler.OverviewPage.recommendation', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='diagnostics', full_name='tensorflow.profiler.OverviewPage.diagnostics', index=4, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2733, serialized_end=3102)
_OVERVIEWPAGEANALYSIS.fields_by_name['top_device_ops'].message_type = _OVERVIEWTFOP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['input_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['host_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['device_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['documentation_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['recommendation'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_OVERVIEWPAGERECOMMENDATION.fields_by_name['faq_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERECOMMENDATION.fields_by_name['inference_tips'].message_type = _OVERVIEWPAGETIP
_OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY.containing_type = _OVERVIEWPAGERUNENVIRONMENT
_OVERVIEWPAGERUNENVIRONMENT.fields_by_name['hostnames'].message_type = _OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY
_OVERVIEWPAGERUNENVIRONMENT.fields_by_name['host_independent_job_info'].message_type = _OVERVIEWPAGEHOSTINDEPENDENTJOBINFO
_OVERVIEWPAGERUNENVIRONMENT.fields_by_name['host_dependent_job_info'].message_type = _OVERVIEWPAGEHOSTDEPENDENTJOBINFO
_OVERVIEWPAGE.fields_by_name['run_environment'].message_type = _OVERVIEWPAGERUNENVIRONMENT
_OVERVIEWPAGE.fields_by_name['input_analysis'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_input__pipeline__pb2._INPUTPIPELINEANALYSISRESULT
_OVERVIEWPAGE.fields_by_name['analysis'].message_type = _OVERVIEWPAGEANALYSIS
_OVERVIEWPAGE.fields_by_name['recommendation'].message_type = _OVERVIEWPAGERECOMMENDATION
_OVERVIEWPAGE.fields_by_name['diagnostics'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_diagnostics__pb2._DIAGNOSTICS
DESCRIPTOR.message_types_by_name['OverviewTfOp'] = _OVERVIEWTFOP
DESCRIPTOR.message_types_by_name['OverviewPageAnalysis'] = _OVERVIEWPAGEANALYSIS
DESCRIPTOR.message_types_by_name['OverviewPageTip'] = _OVERVIEWPAGETIP
DESCRIPTOR.message_types_by_name['GenericRecommendation'] = _GENERICRECOMMENDATION
DESCRIPTOR.message_types_by_name['OverviewPageRecommendation'] = _OVERVIEWPAGERECOMMENDATION
DESCRIPTOR.message_types_by_name['OverviewPageHostIndependentJobInfo'] = _OVERVIEWPAGEHOSTINDEPENDENTJOBINFO
DESCRIPTOR.message_types_by_name['OverviewPageHostDependentJobInfo'] = _OVERVIEWPAGEHOSTDEPENDENTJOBINFO
DESCRIPTOR.message_types_by_name['OverviewPageRunEnvironment'] = _OVERVIEWPAGERUNENVIRONMENT
DESCRIPTOR.message_types_by_name['OverviewPage'] = _OVERVIEWPAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
OverviewTfOp = _reflection.GeneratedProtocolMessageType('OverviewTfOp', (_message.Message,), {'DESCRIPTOR': _OVERVIEWTFOP, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewTfOp)
OverviewPageAnalysis = _reflection.GeneratedProtocolMessageType('OverviewPageAnalysis', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGEANALYSIS, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageAnalysis)
OverviewPageTip = _reflection.GeneratedProtocolMessageType('OverviewPageTip', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGETIP, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageTip)
GenericRecommendation = _reflection.GeneratedProtocolMessageType('GenericRecommendation', (_message.Message,), {'DESCRIPTOR': _GENERICRECOMMENDATION, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(GenericRecommendation)
OverviewPageRecommendation = _reflection.GeneratedProtocolMessageType('OverviewPageRecommendation', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGERECOMMENDATION, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageRecommendation)
OverviewPageHostIndependentJobInfo = _reflection.GeneratedProtocolMessageType('OverviewPageHostIndependentJobInfo', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGEHOSTINDEPENDENTJOBINFO, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageHostIndependentJobInfo)
OverviewPageHostDependentJobInfo = _reflection.GeneratedProtocolMessageType('OverviewPageHostDependentJobInfo', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGEHOSTDEPENDENTJOBINFO, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageHostDependentJobInfo)
OverviewPageRunEnvironment = _reflection.GeneratedProtocolMessageType('OverviewPageRunEnvironment', (_message.Message,), {'HostnamesEntry': _reflection.GeneratedProtocolMessageType('HostnamesEntry', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'}), 'DESCRIPTOR': _OVERVIEWPAGERUNENVIRONMENT, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPageRunEnvironment)
_sym_db.RegisterMessage(OverviewPageRunEnvironment.HostnamesEntry)
OverviewPage = _reflection.GeneratedProtocolMessageType('OverviewPage', (_message.Message,), {'DESCRIPTOR': _OVERVIEWPAGE, '__module__': 'tensorflow.core.profiler.protobuf.overview_page_pb2'})
_sym_db.RegisterMessage(OverviewPage)
_OVERVIEWPAGERUNENVIRONMENT_HOSTNAMESENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/op_profile.proto', package='tensorflow.profiler.op_profile', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n2tensorflow/core/profiler/protobuf/op_profile.proto\x12\x1etensorflow.profiler.op_profile"\xd1\x02\n\x07Profile\x129\n\x0bby_category\x18\x01 \x01(\x0b2$.tensorflow.profiler.op_profile.Node\x128\n\nby_program\x18\x04 \x01(\x0b2$.tensorflow.profiler.op_profile.Node\x12\x13\n\x0bdevice_type\x18\x05 \x01(\t\x12F\n\x18by_category_exclude_idle\x18\x06 \x01(\x0b2$.tensorflow.profiler.op_profile.Node\x12E\n\x17by_program_exclude_idle\x18\x07 \x01(\x0b2$.tensorflow.profiler.op_profile.NodeJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04R\x14by_program_structureR\x0bper_program"\xb4\x05\n\x04Node\x12\x0c\n\x04name\x18\x01 \x01(\t\x128\n\x07metrics\x18\x02 \x01(\x0b2\'.tensorflow.profiler.op_profile.Metrics\x126\n\x08children\x18\x03 \x03(\x0b2$.tensorflow.profiler.op_profile.Node\x12L\n\x08category\x18\x04 \x01(\x0b28.tensorflow.profiler.op_profile.Node.InstructionCategoryH\x00\x12B\n\x03xla\x18\x05 \x01(\x0b23.tensorflow.profiler.op_profile.Node.XLAInstructionH\x00\x12\x14\n\x0cnum_children\x18\x06 \x01(\x05\x1a\x15\n\x13InstructionCategory\x1a\xe0\x02\n\x0eXLAInstruction\x12\n\n\x02op\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x12\n\nprovenance\x18\x03 \x01(\t\x12\x10\n\x08category\x18\x04 \x01(\t\x12R\n\x06layout\x18\x05 \x01(\x0b2B.tensorflow.profiler.op_profile.Node.XLAInstruction.LayoutAnalysis\x1a\xb3\x01\n\x0eLayoutAnalysis\x12`\n\ndimensions\x18\x01 \x03(\x0b2L.tensorflow.profiler.op_profile.Node.XLAInstruction.LayoutAnalysis.Dimension\x1a?\n\tDimension\x12\x0c\n\x04size\x18\x01 \x01(\x05\x12\x11\n\talignment\x18\x02 \x01(\x05\x12\x11\n\tsemantics\x18\x03 \x01(\tB\n\n\x08contents"\x81\x01\n\x07Metrics\x12\x0c\n\x04time\x18\x01 \x01(\x01\x12\r\n\x05flops\x18\x02 \x01(\x01\x12\x18\n\x10memory_bandwidth\x18\x03 \x01(\x01\x12\x10\n\x08raw_time\x18\x0b \x01(\x01\x12\x11\n\traw_flops\x18\x0c \x01(\x01\x12\x1a\n\x12raw_bytes_accessed\x18\r \x01(\x01b\x06proto3')
_PROFILE = _descriptor.Descriptor(name='Profile', full_name='tensorflow.profiler.op_profile.Profile', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='by_category', full_name='tensorflow.profiler.op_profile.Profile.by_category', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='by_program', full_name='tensorflow.profiler.op_profile.Profile.by_program', index=1, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_type', full_name='tensorflow.profiler.op_profile.Profile.device_type', index=2, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='by_category_exclude_idle', full_name='tensorflow.profiler.op_profile.Profile.by_category_exclude_idle', index=3, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='by_program_exclude_idle', full_name='tensorflow.profiler.op_profile.Profile.by_program_exclude_idle', index=4, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=87, serialized_end=424)
_NODE_INSTRUCTIONCATEGORY = _descriptor.Descriptor(name='InstructionCategory', full_name='tensorflow.profiler.op_profile.Node.InstructionCategory', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=731, serialized_end=752)
_NODE_XLAINSTRUCTION_LAYOUTANALYSIS_DIMENSION = _descriptor.Descriptor(name='Dimension', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.LayoutAnalysis.Dimension', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='size', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.LayoutAnalysis.Dimension.size', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='alignment', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.LayoutAnalysis.Dimension.alignment', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='semantics', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.LayoutAnalysis.Dimension.semantics', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1044, serialized_end=1107)
_NODE_XLAINSTRUCTION_LAYOUTANALYSIS = _descriptor.Descriptor(name='LayoutAnalysis', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.LayoutAnalysis', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dimensions', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.LayoutAnalysis.dimensions', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_NODE_XLAINSTRUCTION_LAYOUTANALYSIS_DIMENSION], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=928, serialized_end=1107)
_NODE_XLAINSTRUCTION = _descriptor.Descriptor(name='XLAInstruction', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.op', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='expression', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.expression', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='provenance', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.provenance', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='category', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.category', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='layout', full_name='tensorflow.profiler.op_profile.Node.XLAInstruction.layout', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_NODE_XLAINSTRUCTION_LAYOUTANALYSIS], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=755, serialized_end=1107)
_NODE = _descriptor.Descriptor(name='Node', full_name='tensorflow.profiler.op_profile.Node', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.op_profile.Node.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metrics', full_name='tensorflow.profiler.op_profile.Node.metrics', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='children', full_name='tensorflow.profiler.op_profile.Node.children', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='category', full_name='tensorflow.profiler.op_profile.Node.category', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='xla', full_name='tensorflow.profiler.op_profile.Node.xla', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_children', full_name='tensorflow.profiler.op_profile.Node.num_children', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_NODE_INSTRUCTIONCATEGORY, _NODE_XLAINSTRUCTION], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='contents', full_name='tensorflow.profiler.op_profile.Node.contents', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=427, serialized_end=1119)
_METRICS = _descriptor.Descriptor(name='Metrics', full_name='tensorflow.profiler.op_profile.Metrics', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='time', full_name='tensorflow.profiler.op_profile.Metrics.time', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='flops', full_name='tensorflow.profiler.op_profile.Metrics.flops', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_bandwidth', full_name='tensorflow.profiler.op_profile.Metrics.memory_bandwidth', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='raw_time', full_name='tensorflow.profiler.op_profile.Metrics.raw_time', index=3, number=11, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='raw_flops', full_name='tensorflow.profiler.op_profile.Metrics.raw_flops', index=4, number=12, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='raw_bytes_accessed', full_name='tensorflow.profiler.op_profile.Metrics.raw_bytes_accessed', index=5, number=13, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1122, serialized_end=1251)
_PROFILE.fields_by_name['by_category'].message_type = _NODE
_PROFILE.fields_by_name['by_program'].message_type = _NODE
_PROFILE.fields_by_name['by_category_exclude_idle'].message_type = _NODE
_PROFILE.fields_by_name['by_program_exclude_idle'].message_type = _NODE
_NODE_INSTRUCTIONCATEGORY.containing_type = _NODE
_NODE_XLAINSTRUCTION_LAYOUTANALYSIS_DIMENSION.containing_type = _NODE_XLAINSTRUCTION_LAYOUTANALYSIS
_NODE_XLAINSTRUCTION_LAYOUTANALYSIS.fields_by_name['dimensions'].message_type = _NODE_XLAINSTRUCTION_LAYOUTANALYSIS_DIMENSION
_NODE_XLAINSTRUCTION_LAYOUTANALYSIS.containing_type = _NODE_XLAINSTRUCTION
_NODE_XLAINSTRUCTION.fields_by_name['layout'].message_type = _NODE_XLAINSTRUCTION_LAYOUTANALYSIS
_NODE_XLAINSTRUCTION.containing_type = _NODE
_NODE.fields_by_name['metrics'].message_type = _METRICS
_NODE.fields_by_name['children'].message_type = _NODE
_NODE.fields_by_name['category'].message_type = _NODE_INSTRUCTIONCATEGORY
_NODE.fields_by_name['xla'].message_type = _NODE_XLAINSTRUCTION
_NODE.oneofs_by_name['contents'].fields.append(_NODE.fields_by_name['category'])
_NODE.fields_by_name['category'].containing_oneof = _NODE.oneofs_by_name['contents']
_NODE.oneofs_by_name['contents'].fields.append(_NODE.fields_by_name['xla'])
_NODE.fields_by_name['xla'].containing_oneof = _NODE.oneofs_by_name['contents']
DESCRIPTOR.message_types_by_name['Profile'] = _PROFILE
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Metrics'] = _METRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
Profile = _reflection.GeneratedProtocolMessageType('Profile', (_message.Message,), {'DESCRIPTOR': _PROFILE, '__module__': 'tensorflow.core.profiler.protobuf.op_profile_pb2'})
_sym_db.RegisterMessage(Profile)
Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {'InstructionCategory': _reflection.GeneratedProtocolMessageType('InstructionCategory', (_message.Message,), {'DESCRIPTOR': _NODE_INSTRUCTIONCATEGORY, '__module__': 'tensorflow.core.profiler.protobuf.op_profile_pb2'}), 'XLAInstruction': _reflection.GeneratedProtocolMessageType('XLAInstruction', (_message.Message,), {'LayoutAnalysis': _reflection.GeneratedProtocolMessageType('LayoutAnalysis', (_message.Message,), {'Dimension': _reflection.GeneratedProtocolMessageType('Dimension', (_message.Message,), {'DESCRIPTOR': _NODE_XLAINSTRUCTION_LAYOUTANALYSIS_DIMENSION, '__module__': 'tensorflow.core.profiler.protobuf.op_profile_pb2'}), 'DESCRIPTOR': _NODE_XLAINSTRUCTION_LAYOUTANALYSIS, '__module__': 'tensorflow.core.profiler.protobuf.op_profile_pb2'}), 'DESCRIPTOR': _NODE_XLAINSTRUCTION, '__module__': 'tensorflow.core.profiler.protobuf.op_profile_pb2'}), 'DESCRIPTOR': _NODE, '__module__': 'tensorflow.core.profiler.protobuf.op_profile_pb2'})
_sym_db.RegisterMessage(Node)
_sym_db.RegisterMessage(Node.InstructionCategory)
_sym_db.RegisterMessage(Node.XLAInstruction)
_sym_db.RegisterMessage(Node.XLAInstruction.LayoutAnalysis)
_sym_db.RegisterMessage(Node.XLAInstruction.LayoutAnalysis.Dimension)
Metrics = _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {'DESCRIPTOR': _METRICS, '__module__': 'tensorflow.core.profiler.protobuf.op_profile_pb2'})
_sym_db.RegisterMessage(Metrics)




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/full_type.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0eFullTypeProtosP\x01ZPgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/full_type_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/core/framework/full_type.proto\x12\ntensorflow"r\n\x0bFullTypeDef\x12\'\n\x07type_id\x18\x01 \x01(\x0e2\x16.tensorflow.FullTypeId\x12%\n\x04args\x18\x02 \x03(\x0b2\x17.tensorflow.FullTypeDef\x12\x0b\n\x01s\x18\x03 \x01(\tH\x00B\x06\n\x04attr*\xac\x03\n\nFullTypeId\x12\r\n\tTFT_UNSET\x10\x00\x12\x0b\n\x07TFT_VAR\x10\x01\x12\x0b\n\x07TFT_ANY\x10\x02\x12\x0f\n\x0bTFT_PRODUCT\x10\x03\x12\x10\n\x0cTFT_CALLABLE\x10d\x12\x0f\n\nTFT_TENSOR\x10\xe8\x07\x12\x0e\n\tTFT_ARRAY\x10\xe9\x07\x12\x11\n\x0cTFT_OPTIONAL\x10\xea\x07\x12\x10\n\x0bTFT_DATASET\x10\xf6N\x12\r\n\x08TFT_BOOL\x10\xc8\x01\x12\x0e\n\tTFT_UINT8\x10\xc9\x01\x12\x0f\n\nTFT_UINT16\x10\xca\x01\x12\x0f\n\nTFT_UINT32\x10\xcb\x01\x12\x0f\n\nTFT_UINT64\x10\xcc\x01\x12\r\n\x08TFT_INT8\x10\xcd\x01\x12\x0e\n\tTFT_INT16\x10\xce\x01\x12\x0e\n\tTFT_INT32\x10\xcf\x01\x12\x0e\n\tTFT_INT64\x10\xd0\x01\x12\r\n\x08TFT_HALF\x10\xd1\x01\x12\x0e\n\tTFT_FLOAT\x10\xd2\x01\x12\x0f\n\nTFT_DOUBLE\x10\xd3\x01\x12\x11\n\x0cTFT_BFLOAT16\x10\xd7\x01\x12\x12\n\rTFT_COMPLEX64\x10\xd4\x01\x12\x13\n\x0eTFT_COMPLEX128\x10\xd5\x01\x12\x0f\n\nTFT_STRING\x10\xd6\x01B\x81\x01\n\x18org.tensorflow.frameworkB\x0eFullTypeProtosP\x01ZPgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/full_type_go_proto\xf8\x01\x01b\x06proto3')
_FULLTYPEID = _descriptor.EnumDescriptor(name='FullTypeId', full_name='tensorflow.FullTypeId', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='TFT_UNSET', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_VAR', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_ANY', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_PRODUCT', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_CALLABLE', index=4, number=100, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_TENSOR', index=5, number=1000, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_ARRAY', index=6, number=1001, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_OPTIONAL', index=7, number=1002, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_DATASET', index=8, number=10102, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_BOOL', index=9, number=200, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_UINT8', index=10, number=201, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_UINT16', index=11, number=202, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_UINT32', index=12, number=203, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_UINT64', index=13, number=204, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_INT8', index=14, number=205, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_INT16', index=15, number=206, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_INT32', index=16, number=207, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_INT64', index=17, number=208, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_HALF', index=18, number=209, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_FLOAT', index=19, number=210, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_DOUBLE', index=20, number=211, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_BFLOAT16', index=21, number=215, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_COMPLEX64', index=22, number=212, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_COMPLEX128', index=23, number=213, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TFT_STRING', index=24, number=214, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=174, serialized_end=602)
_sym_db.RegisterEnumDescriptor(_FULLTYPEID)
FullTypeId = enum_type_wrapper.EnumTypeWrapper(_FULLTYPEID)
TFT_UNSET = 0
TFT_VAR = 1
TFT_ANY = 2
TFT_PRODUCT = 3
TFT_CALLABLE = 100
TFT_TENSOR = 1000
TFT_ARRAY = 1001
TFT_OPTIONAL = 1002
TFT_DATASET = 10102
TFT_BOOL = 200
TFT_UINT8 = 201
TFT_UINT16 = 202
TFT_UINT32 = 203
TFT_UINT64 = 204
TFT_INT8 = 205
TFT_INT16 = 206
TFT_INT32 = 207
TFT_INT64 = 208
TFT_HALF = 209
TFT_FLOAT = 210
TFT_DOUBLE = 211
TFT_BFLOAT16 = 215
TFT_COMPLEX64 = 212
TFT_COMPLEX128 = 213
TFT_STRING = 214
_FULLTYPEDEF = _descriptor.Descriptor(name='FullTypeDef', full_name='tensorflow.FullTypeDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='type_id', full_name='tensorflow.FullTypeDef.type_id', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='args', full_name='tensorflow.FullTypeDef.args', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='s', full_name='tensorflow.FullTypeDef.s', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='attr', full_name='tensorflow.FullTypeDef.attr', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=57, serialized_end=171)
_FULLTYPEDEF.fields_by_name['type_id'].enum_type = _FULLTYPEID
_FULLTYPEDEF.fields_by_name['args'].message_type = _FULLTYPEDEF
_FULLTYPEDEF.oneofs_by_name['attr'].fields.append(_FULLTYPEDEF.fields_by_name['s'])
_FULLTYPEDEF.fields_by_name['s'].containing_oneof = _FULLTYPEDEF.oneofs_by_name['attr']
DESCRIPTOR.message_types_by_name['FullTypeDef'] = _FULLTYPEDEF
DESCRIPTOR.enum_types_by_name['FullTypeId'] = _FULLTYPEID
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
FullTypeDef = _reflection.GeneratedProtocolMessageType('FullTypeDef', (_message.Message,), {'DESCRIPTOR': _FULLTYPEDEF, '__module__': 'tensorflow.core.framework.full_type_pb2'})
_sym_db.RegisterMessage(FullTypeDef)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/memory_profile.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n6tensorflow/core/profiler/protobuf/memory_profile.proto\x12\x13tensorflow.profiler"\xa1\x01\n\x16MemoryAggregationStats\x12\x1c\n\x14stack_reserved_bytes\x18\x01 \x01(\x03\x12\x1c\n\x14heap_allocated_bytes\x18\x02 \x01(\x03\x12\x19\n\x11free_memory_bytes\x18\x03 \x01(\x03\x12\x15\n\rfragmentation\x18\x04 \x01(\x01\x12\x19\n\x11peak_bytes_in_use\x18\x05 \x01(\x03"\xfd\x01\n\x16MemoryActivityMetadata\x12<\n\x0fmemory_activity\x18\x01 \x01(\x0e2#.tensorflow.profiler.MemoryActivity\x12\x17\n\x0frequested_bytes\x18\x02 \x01(\x03\x12\x18\n\x10allocation_bytes\x18\x03 \x01(\x03\x12\x0f\n\x07address\x18\x04 \x01(\x04\x12\x12\n\ntf_op_name\x18\x05 \x01(\t\x12\x0f\n\x07step_id\x18\x06 \x01(\x03\x12\x13\n\x0bregion_type\x18\x07 \x01(\t\x12\x11\n\tdata_type\x18\x08 \x01(\t\x12\x14\n\x0ctensor_shape\x18\t \x01(\t"\xbf\x01\n\x15MemoryProfileSnapshot\x12\x16\n\x0etime_offset_ps\x18\x01 \x01(\x03\x12F\n\x11aggregation_stats\x18\x02 \x01(\x0b2+.tensorflow.profiler.MemoryAggregationStats\x12F\n\x11activity_metadata\x18\x03 \x01(\x0b2+.tensorflow.profiler.MemoryActivityMetadata"\xaf\x01\n\x14MemoryProfileSummary\x12!\n\x19peak_bytes_usage_lifetime\x18\x01 \x01(\x03\x12?\n\npeak_stats\x18\x02 \x01(\x0b2+.tensorflow.profiler.MemoryAggregationStats\x12\x1a\n\x12peak_stats_time_ps\x18\x03 \x01(\x03\x12\x17\n\x0fmemory_capacity\x18\x04 \x01(\x03"Z\n\x10ActiveAllocation\x12\x16\n\x0esnapshot_index\x18\x01 \x01(\x03\x12\x15\n\rspecial_index\x18\x02 \x01(\x03\x12\x17\n\x0fnum_occurrences\x18\x03 \x01(\x03"\xba\x02\n\x19PerAllocatorMemoryProfile\x12L\n\x18memory_profile_snapshots\x18\x01 \x03(\x0b2*.tensorflow.profiler.MemoryProfileSnapshot\x12B\n\x0fprofile_summary\x18\x02 \x01(\x0b2).tensorflow.profiler.MemoryProfileSummary\x12A\n\x12active_allocations\x18\x03 \x03(\x0b2%.tensorflow.profiler.ActiveAllocation\x12H\n\x13special_allocations\x18\x04 \x03(\x0b2+.tensorflow.profiler.MemoryActivityMetadata"\x97\x02\n\rMemoryProfile\x12g\n\x1cmemory_profile_per_allocator\x18\x01 \x03(\x0b2A.tensorflow.profiler.MemoryProfile.MemoryProfilePerAllocatorEntry\x12\x11\n\tnum_hosts\x18\x02 \x01(\x05\x12\x12\n\nmemory_ids\x18\x03 \x03(\t\x1ap\n\x1eMemoryProfilePerAllocatorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b2..tensorflow.profiler.PerAllocatorMemoryProfile:\x028\x01J\x04\x08\x04\x10\x05*h\n\x0eMemoryActivity\x12\x14\n\x10UNKNOWN_ACTIVITY\x10\x00\x12\x0e\n\nALLOCATION\x10\x01\x12\x10\n\x0cDEALLOCATION\x10\x02\x12\x0f\n\x0bRESERVATION\x10\x03\x12\r\n\tEXPANSION\x10\x04b\x06proto3')
_MEMORYACTIVITY = _descriptor.EnumDescriptor(name='MemoryActivity', full_name='tensorflow.profiler.MemoryActivity', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNKNOWN_ACTIVITY', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='ALLOCATION', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DEALLOCATION', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='RESERVATION', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='EXPANSION', index=4, number=4, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1562, serialized_end=1666)
_sym_db.RegisterEnumDescriptor(_MEMORYACTIVITY)
MemoryActivity = enum_type_wrapper.EnumTypeWrapper(_MEMORYACTIVITY)
UNKNOWN_ACTIVITY = 0
ALLOCATION = 1
DEALLOCATION = 2
RESERVATION = 3
EXPANSION = 4
_MEMORYAGGREGATIONSTATS = _descriptor.Descriptor(name='MemoryAggregationStats', full_name='tensorflow.profiler.MemoryAggregationStats', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='stack_reserved_bytes', full_name='tensorflow.profiler.MemoryAggregationStats.stack_reserved_bytes', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='heap_allocated_bytes', full_name='tensorflow.profiler.MemoryAggregationStats.heap_allocated_bytes', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='free_memory_bytes', full_name='tensorflow.profiler.MemoryAggregationStats.free_memory_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fragmentation', full_name='tensorflow.profiler.MemoryAggregationStats.fragmentation', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_bytes_in_use', full_name='tensorflow.profiler.MemoryAggregationStats.peak_bytes_in_use', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=80, serialized_end=241)
_MEMORYACTIVITYMETADATA = _descriptor.Descriptor(name='MemoryActivityMetadata', full_name='tensorflow.profiler.MemoryActivityMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='memory_activity', full_name='tensorflow.profiler.MemoryActivityMetadata.memory_activity', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='requested_bytes', full_name='tensorflow.profiler.MemoryActivityMetadata.requested_bytes', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allocation_bytes', full_name='tensorflow.profiler.MemoryActivityMetadata.allocation_bytes', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='address', full_name='tensorflow.profiler.MemoryActivityMetadata.address', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_op_name', full_name='tensorflow.profiler.MemoryActivityMetadata.tf_op_name', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_id', full_name='tensorflow.profiler.MemoryActivityMetadata.step_id', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='region_type', full_name='tensorflow.profiler.MemoryActivityMetadata.region_type', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_type', full_name='tensorflow.profiler.MemoryActivityMetadata.data_type', index=7, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_shape', full_name='tensorflow.profiler.MemoryActivityMetadata.tensor_shape', index=8, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=244, serialized_end=497)
_MEMORYPROFILESNAPSHOT = _descriptor.Descriptor(name='MemoryProfileSnapshot', full_name='tensorflow.profiler.MemoryProfileSnapshot', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='time_offset_ps', full_name='tensorflow.profiler.MemoryProfileSnapshot.time_offset_ps', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='aggregation_stats', full_name='tensorflow.profiler.MemoryProfileSnapshot.aggregation_stats', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='activity_metadata', full_name='tensorflow.profiler.MemoryProfileSnapshot.activity_metadata', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=500, serialized_end=691)
_MEMORYPROFILESUMMARY = _descriptor.Descriptor(name='MemoryProfileSummary', full_name='tensorflow.profiler.MemoryProfileSummary', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='peak_bytes_usage_lifetime', full_name='tensorflow.profiler.MemoryProfileSummary.peak_bytes_usage_lifetime', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_stats', full_name='tensorflow.profiler.MemoryProfileSummary.peak_stats', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_stats_time_ps', full_name='tensorflow.profiler.MemoryProfileSummary.peak_stats_time_ps', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_capacity', full_name='tensorflow.profiler.MemoryProfileSummary.memory_capacity', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=694, serialized_end=869)
_ACTIVEALLOCATION = _descriptor.Descriptor(name='ActiveAllocation', full_name='tensorflow.profiler.ActiveAllocation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='snapshot_index', full_name='tensorflow.profiler.ActiveAllocation.snapshot_index', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='special_index', full_name='tensorflow.profiler.ActiveAllocation.special_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_occurrences', full_name='tensorflow.profiler.ActiveAllocation.num_occurrences', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=871, serialized_end=961)
_PERALLOCATORMEMORYPROFILE = _descriptor.Descriptor(name='PerAllocatorMemoryProfile', full_name='tensorflow.profiler.PerAllocatorMemoryProfile', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='memory_profile_snapshots', full_name='tensorflow.profiler.PerAllocatorMemoryProfile.memory_profile_snapshots', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='profile_summary', full_name='tensorflow.profiler.PerAllocatorMemoryProfile.profile_summary', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='active_allocations', full_name='tensorflow.profiler.PerAllocatorMemoryProfile.active_allocations', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='special_allocations', full_name='tensorflow.profiler.PerAllocatorMemoryProfile.special_allocations', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=964, serialized_end=1278)
_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY = _descriptor.Descriptor(name='MemoryProfilePerAllocatorEntry', full_name='tensorflow.profiler.MemoryProfile.MemoryProfilePerAllocatorEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.MemoryProfile.MemoryProfilePerAllocatorEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.MemoryProfile.MemoryProfilePerAllocatorEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1442, serialized_end=1554)
_MEMORYPROFILE = _descriptor.Descriptor(name='MemoryProfile', full_name='tensorflow.profiler.MemoryProfile', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='memory_profile_per_allocator', full_name='tensorflow.profiler.MemoryProfile.memory_profile_per_allocator', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_hosts', full_name='tensorflow.profiler.MemoryProfile.num_hosts', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='memory_ids', full_name='tensorflow.profiler.MemoryProfile.memory_ids', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1281, serialized_end=1560)
_MEMORYACTIVITYMETADATA.fields_by_name['memory_activity'].enum_type = _MEMORYACTIVITY
_MEMORYPROFILESNAPSHOT.fields_by_name['aggregation_stats'].message_type = _MEMORYAGGREGATIONSTATS
_MEMORYPROFILESNAPSHOT.fields_by_name['activity_metadata'].message_type = _MEMORYACTIVITYMETADATA
_MEMORYPROFILESUMMARY.fields_by_name['peak_stats'].message_type = _MEMORYAGGREGATIONSTATS
_PERALLOCATORMEMORYPROFILE.fields_by_name['memory_profile_snapshots'].message_type = _MEMORYPROFILESNAPSHOT
_PERALLOCATORMEMORYPROFILE.fields_by_name['profile_summary'].message_type = _MEMORYPROFILESUMMARY
_PERALLOCATORMEMORYPROFILE.fields_by_name['active_allocations'].message_type = _ACTIVEALLOCATION
_PERALLOCATORMEMORYPROFILE.fields_by_name['special_allocations'].message_type = _MEMORYACTIVITYMETADATA
_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY.fields_by_name['value'].message_type = _PERALLOCATORMEMORYPROFILE
_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY.containing_type = _MEMORYPROFILE
_MEMORYPROFILE.fields_by_name['memory_profile_per_allocator'].message_type = _MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY
DESCRIPTOR.message_types_by_name['MemoryAggregationStats'] = _MEMORYAGGREGATIONSTATS
DESCRIPTOR.message_types_by_name['MemoryActivityMetadata'] = _MEMORYACTIVITYMETADATA
DESCRIPTOR.message_types_by_name['MemoryProfileSnapshot'] = _MEMORYPROFILESNAPSHOT
DESCRIPTOR.message_types_by_name['MemoryProfileSummary'] = _MEMORYPROFILESUMMARY
DESCRIPTOR.message_types_by_name['ActiveAllocation'] = _ACTIVEALLOCATION
DESCRIPTOR.message_types_by_name['PerAllocatorMemoryProfile'] = _PERALLOCATORMEMORYPROFILE
DESCRIPTOR.message_types_by_name['MemoryProfile'] = _MEMORYPROFILE
DESCRIPTOR.enum_types_by_name['MemoryActivity'] = _MEMORYACTIVITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
MemoryAggregationStats = _reflection.GeneratedProtocolMessageType('MemoryAggregationStats', (_message.Message,), {'DESCRIPTOR': _MEMORYAGGREGATIONSTATS, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryAggregationStats)
MemoryActivityMetadata = _reflection.GeneratedProtocolMessageType('MemoryActivityMetadata', (_message.Message,), {'DESCRIPTOR': _MEMORYACTIVITYMETADATA, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryActivityMetadata)
MemoryProfileSnapshot = _reflection.GeneratedProtocolMessageType('MemoryProfileSnapshot', (_message.Message,), {'DESCRIPTOR': _MEMORYPROFILESNAPSHOT, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryProfileSnapshot)
MemoryProfileSummary = _reflection.GeneratedProtocolMessageType('MemoryProfileSummary', (_message.Message,), {'DESCRIPTOR': _MEMORYPROFILESUMMARY, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryProfileSummary)
ActiveAllocation = _reflection.GeneratedProtocolMessageType('ActiveAllocation', (_message.Message,), {'DESCRIPTOR': _ACTIVEALLOCATION, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(ActiveAllocation)
PerAllocatorMemoryProfile = _reflection.GeneratedProtocolMessageType('PerAllocatorMemoryProfile', (_message.Message,), {'DESCRIPTOR': _PERALLOCATORMEMORYPROFILE, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(PerAllocatorMemoryProfile)
MemoryProfile = _reflection.GeneratedProtocolMessageType('MemoryProfile', (_message.Message,), {'MemoryProfilePerAllocatorEntry': _reflection.GeneratedProtocolMessageType('MemoryProfilePerAllocatorEntry', (_message.Message,), {'DESCRIPTOR': _MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'}), 'DESCRIPTOR': _MEMORYPROFILE, '__module__': 'tensorflow.core.profiler.protobuf.memory_profile_pb2'})
_sym_db.RegisterMessage(MemoryProfile)
_sym_db.RegisterMessage(MemoryProfile.MemoryProfilePerAllocatorEntry)
_MEMORYPROFILE_MEMORYPROFILEPERALLOCATORENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/trackable_object_graph.proto', package='tensorflow', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n5tensorflow/core/protobuf/trackable_object_graph.proto\x12\ntensorflow"\x83\x05\n\x14TrackableObjectGraph\x12?\n\x05nodes\x18\x01 \x03(\x0b20.tensorflow.TrackableObjectGraph.TrackableObject\x1a\xa9\x04\n\x0fTrackableObject\x12R\n\x08children\x18\x01 \x03(\x0b2@.tensorflow.TrackableObjectGraph.TrackableObject.ObjectReference\x12U\n\nattributes\x18\x02 \x03(\x0b2A.tensorflow.TrackableObjectGraph.TrackableObject.SerializedTensor\x12^\n\x0eslot_variables\x18\x03 \x03(\x0b2F.tensorflow.TrackableObjectGraph.TrackableObject.SlotVariableReference\x1a6\n\x0fObjectReference\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x12\n\nlocal_name\x18\x02 \x01(\t\x1ae\n\x10SerializedTensor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\x16\n\x0echeckpoint_key\x18\x03 \x01(\t\x12\x18\n\x10optional_restore\x18\x04 \x01(\x08\x1al\n\x15SlotVariableReference\x12!\n\x19original_variable_node_id\x18\x01 \x01(\x05\x12\x11\n\tslot_name\x18\x02 \x01(\t\x12\x1d\n\x15slot_variable_node_id\x18\x03 \x01(\x05BZZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3')
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_OBJECTREFERENCE = _descriptor.Descriptor(name='ObjectReference', full_name='tensorflow.TrackableObjectGraph.TrackableObject.ObjectReference', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node_id', full_name='tensorflow.TrackableObjectGraph.TrackableObject.ObjectReference.node_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='local_name', full_name='tensorflow.TrackableObjectGraph.TrackableObject.ObjectReference.local_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=446, serialized_end=500)
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SERIALIZEDTENSOR = _descriptor.Descriptor(name='SerializedTensor', full_name='tensorflow.TrackableObjectGraph.TrackableObject.SerializedTensor', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.TrackableObjectGraph.TrackableObject.SerializedTensor.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='full_name', full_name='tensorflow.TrackableObjectGraph.TrackableObject.SerializedTensor.full_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='checkpoint_key', full_name='tensorflow.TrackableObjectGraph.TrackableObject.SerializedTensor.checkpoint_key', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='optional_restore', full_name='tensorflow.TrackableObjectGraph.TrackableObject.SerializedTensor.optional_restore', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=502, serialized_end=603)
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SLOTVARIABLEREFERENCE = _descriptor.Descriptor(name='SlotVariableReference', full_name='tensorflow.TrackableObjectGraph.TrackableObject.SlotVariableReference', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='original_variable_node_id', full_name='tensorflow.TrackableObjectGraph.TrackableObject.SlotVariableReference.original_variable_node_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='slot_name', full_name='tensorflow.TrackableObjectGraph.TrackableObject.SlotVariableReference.slot_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='slot_variable_node_id', full_name='tensorflow.TrackableObjectGraph.TrackableObject.SlotVariableReference.slot_variable_node_id', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=605, serialized_end=713)
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT = _descriptor.Descriptor(name='TrackableObject', full_name='tensorflow.TrackableObjectGraph.TrackableObject', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='children', full_name='tensorflow.TrackableObjectGraph.TrackableObject.children', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='attributes', full_name='tensorflow.TrackableObjectGraph.TrackableObject.attributes', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='slot_variables', full_name='tensorflow.TrackableObjectGraph.TrackableObject.slot_variables', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_OBJECTREFERENCE, _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SERIALIZEDTENSOR, _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SLOTVARIABLEREFERENCE], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=160, serialized_end=713)
_TRACKABLEOBJECTGRAPH = _descriptor.Descriptor(name='TrackableObjectGraph', full_name='tensorflow.TrackableObjectGraph', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='nodes', full_name='tensorflow.TrackableObjectGraph.nodes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=70, serialized_end=713)
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_OBJECTREFERENCE.containing_type = _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SERIALIZEDTENSOR.containing_type = _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SLOTVARIABLEREFERENCE.containing_type = _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT.fields_by_name['children'].message_type = _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_OBJECTREFERENCE
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT.fields_by_name['attributes'].message_type = _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SERIALIZEDTENSOR
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT.fields_by_name['slot_variables'].message_type = _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SLOTVARIABLEREFERENCE
_TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT.containing_type = _TRACKABLEOBJECTGRAPH
_TRACKABLEOBJECTGRAPH.fields_by_name['nodes'].message_type = _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT
DESCRIPTOR.message_types_by_name['TrackableObjectGraph'] = _TRACKABLEOBJECTGRAPH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TrackableObjectGraph = _reflection.GeneratedProtocolMessageType('TrackableObjectGraph', (_message.Message,), {'TrackableObject': _reflection.GeneratedProtocolMessageType('TrackableObject', (_message.Message,), {'ObjectReference': _reflection.GeneratedProtocolMessageType('ObjectReference', (_message.Message,), {'DESCRIPTOR': _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_OBJECTREFERENCE, '__module__': 'tensorflow.core.protobuf.trackable_object_graph_pb2'}), 'SerializedTensor': _reflection.GeneratedProtocolMessageType('SerializedTensor', (_message.Message,), {'DESCRIPTOR': _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SERIALIZEDTENSOR, '__module__': 'tensorflow.core.protobuf.trackable_object_graph_pb2'}), 'SlotVariableReference': _reflection.GeneratedProtocolMessageType('SlotVariableReference', (_message.Message,), {'DESCRIPTOR': _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT_SLOTVARIABLEREFERENCE, '__module__': 'tensorflow.core.protobuf.trackable_object_graph_pb2'}), 'DESCRIPTOR': _TRACKABLEOBJECTGRAPH_TRACKABLEOBJECT, '__module__': 'tensorflow.core.protobuf.trackable_object_graph_pb2'}), 'DESCRIPTOR': _TRACKABLEOBJECTGRAPH, '__module__': 'tensorflow.core.protobuf.trackable_object_graph_pb2'})
_sym_db.RegisterMessage(TrackableObjectGraph)
_sym_db.RegisterMessage(TrackableObjectGraph.TrackableObject)
_sym_db.RegisterMessage(TrackableObjectGraph.TrackableObject.ObjectReference)
_sym_db.RegisterMessage(TrackableObjectGraph.TrackableObject.SerializedTensor)
_sym_db.RegisterMessage(TrackableObjectGraph.TrackableObject.SlotVariableReference)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/grappler/optimizers/inference/batch_op_rewriter.proto', package='tensorflow.serving', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\nEtensorflow/core/grappler/optimizers/inference/batch_op_rewriter.proto\x12\x12tensorflow.serving\x1a\x1egoogle/protobuf/wrappers.proto"\xe1\x04\n\x14BatchOpRewriteConfig\x123\n+enable_adaptive_shared_batching_thread_pool\x18\x04 \x01(\x08\x12d\n\x17model_scheduler_options\x18\x01 \x03(\x0b2C.tensorflow.serving.BatchOpRewriteConfig.ModelSchedulerOptionsEntry\x1a\xa7\x02\n\x1cAdaptiveBatchSchedulerOption\x12@\n\x1amin_inflight_batches_limit\x18\x01 \x01(\x0b2\x1c.google.protobuf.UInt32Value\x12D\n\x1einitial_inflight_batches_limit\x18\x02 \x01(\x0b2\x1c.google.protobuf.UInt32Value\x12@\n\x1amax_inflight_batches_limit\x18\x03 \x01(\x0b2\x1c.google.protobuf.UInt32Value\x12=\n\x17batches_to_average_over\x18\x04 \x01(\x0b2\x1c.google.protobuf.UInt32Value\x1a\x83\x01\n\x1aModelSchedulerOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12T\n\x05value\x18\x02 \x01(\x0b2E.tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption:\x028\x01b\x06proto3', dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR])
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION = _descriptor.Descriptor(name='AdaptiveBatchSchedulerOption', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='min_inflight_batches_limit', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption.min_inflight_batches_limit', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='initial_inflight_batches_limit', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption.initial_inflight_batches_limit', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_inflight_batches_limit', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption.max_inflight_batches_limit', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='batches_to_average_over', full_name='tensorflow.serving.BatchOpRewriteConfig.AdaptiveBatchSchedulerOption.batches_to_average_over', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=306, serialized_end=601)
_BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY = _descriptor.Descriptor(name='ModelSchedulerOptionsEntry', full_name='tensorflow.serving.BatchOpRewriteConfig.ModelSchedulerOptionsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.serving.BatchOpRewriteConfig.ModelSchedulerOptionsEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.serving.BatchOpRewriteConfig.ModelSchedulerOptionsEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=604, serialized_end=735)
_BATCHOPREWRITECONFIG = _descriptor.Descriptor(name='BatchOpRewriteConfig', full_name='tensorflow.serving.BatchOpRewriteConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='enable_adaptive_shared_batching_thread_pool', full_name='tensorflow.serving.BatchOpRewriteConfig.enable_adaptive_shared_batching_thread_pool', index=0, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='model_scheduler_options', full_name='tensorflow.serving.BatchOpRewriteConfig.model_scheduler_options', index=1, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION, _BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=126, serialized_end=735)
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.fields_by_name['min_inflight_batches_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.fields_by_name['initial_inflight_batches_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.fields_by_name['max_inflight_batches_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.fields_by_name['batches_to_average_over'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION.containing_type = _BATCHOPREWRITECONFIG
_BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY.fields_by_name['value'].message_type = _BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION
_BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY.containing_type = _BATCHOPREWRITECONFIG
_BATCHOPREWRITECONFIG.fields_by_name['model_scheduler_options'].message_type = _BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY
DESCRIPTOR.message_types_by_name['BatchOpRewriteConfig'] = _BATCHOPREWRITECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
BatchOpRewriteConfig = _reflection.GeneratedProtocolMessageType('BatchOpRewriteConfig', (_message.Message,), {'AdaptiveBatchSchedulerOption': _reflection.GeneratedProtocolMessageType('AdaptiveBatchSchedulerOption', (_message.Message,), {'DESCRIPTOR': _BATCHOPREWRITECONFIG_ADAPTIVEBATCHSCHEDULEROPTION, '__module__': 'tensorflow.core.grappler.optimizers.inference.batch_op_rewriter_pb2'}), 'ModelSchedulerOptionsEntry': _reflection.GeneratedProtocolMessageType('ModelSchedulerOptionsEntry', (_message.Message,), {'DESCRIPTOR': _BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY, '__module__': 'tensorflow.core.grappler.optimizers.inference.batch_op_rewriter_pb2'}), 'DESCRIPTOR': _BATCHOPREWRITECONFIG, '__module__': 'tensorflow.core.grappler.optimizers.inference.batch_op_rewriter_pb2'})
_sym_db.RegisterMessage(BatchOpRewriteConfig)
_sym_db.RegisterMessage(BatchOpRewriteConfig.AdaptiveBatchSchedulerOption)
_sym_db.RegisterMessage(BatchOpRewriteConfig.ModelSchedulerOptionsEntry)
_BATCHOPREWRITECONFIG_MODELSCHEDULEROPTIONSENTRY._options = None
